@@ -17,6 +17,7 @@ FILE_HORNARRAY = 'CalQubic_HornArray_v*.fits'
 FILE_OPTICS = 'CalQubic_Optics_v*.fits'
 FILE_PRIMBEAM = 'CalQubic_PrimBeam_v*.fits'
 
+
 class QubicCalibration(object):
     """
     Class representing the QUBIC calibration tree. It stores the calibration
@@ -57,9 +58,8 @@ class QubicCalibration(object):
                  ('detarray', self.detarray),
                  ('hornarray', self.hornarray),
                  ('optics', self.optics),
-                 ('primbeam', self.primbeam),
-                ]
-        return '\n'.join([a + ': ' + repr(v) for a,v in state])
+                 ('primbeam', self.primbeam)]
+        return '\n'.join([a + ': ' + repr(v) for a, v in state])
 
     __repr__ = __str__
 
@@ -80,8 +80,8 @@ class QubicCalibration(object):
         if name == 'detarray':
             hdus = fits.open(self.detarray)
             version = hdus[0].header['format version']
-            center, corner = hdus[1].data, hdus[2].data
-            shape = center.shape[:-1]
+            corner = hdus[2].data
+            shape = corner.shape[:-2]
             n = shape[0] * shape[1]
             if version == '1.0':
                 removed = np.zeros(shape, bool)
@@ -91,7 +91,7 @@ class QubicCalibration(object):
                 removed = hdus[3].data.view(bool)
                 index = hdus[4].data
                 quadrant = hdus[5].data
-            return shape, center, corner, removed, index, quadrant
+            return shape, corner, removed, index, quadrant
 
         elif name == 'hornarray':
             hdus = fits.open(self.hornarray)
@@ -101,7 +101,7 @@ class QubicCalibration(object):
 
         elif name == 'optics':
             header = fits.open(self.optics)[0].header
-            return {'focal length':header['flength']}
+            return {'focal length': header['flength']}
 
         elif name == 'primbeam':
             header = fits.open(self.primbeam)[0].header
